@@ -164,7 +164,7 @@ namespace Oxygen
         if( _allWidgets.find( widget ) != _allWidgets.end() ) return false;
 
         #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::Animations::registerWidget - " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")" << std::endl;
+        std::cerr << "Oxygen::Animations::registerWidget - " << widget << " (" << (widget ? G_OBJECT_TYPE_NAME( widget ):"0x0") << ")" << std::endl;
         #endif
 
         Signal destroyId;
@@ -254,10 +254,11 @@ namespace Oxygen
         gdk_window_get_origin( gtk_widget_get_window( combobox ), &targetX, &dummy );
 
         const GtkAllocation comboAllocation( Gtk::gtk_widget_get_allocation( combobox ) );
-        gtk_window_move( window, targetX + comboAllocation.x + 3, y );
+        int uglyShadowWidth=!Gtk::gdk_default_screen_is_composited();
+        gtk_window_move( window, targetX + comboAllocation.x + 3 - uglyShadowWidth, y );
 
         const GtkAllocation widgetAllocation( Gtk::gtk_widget_get_allocation( widget ) );
-        gtk_widget_set_size_request( widget, comboAllocation.width - 6, widgetAllocation.height );
+        gtk_widget_set_size_request( widget, comboAllocation.width - 6 + 2*uglyShadowWidth, widgetAllocation.height );
         #endif
 
         return TRUE;
@@ -280,7 +281,6 @@ namespace Oxygen
         Animations& animations( *static_cast<Animations*>(data) );
         if( !animations.innerShadowsEnabled() ) return TRUE;
 
-        if( Gtk::gtk_combobox_is_tree_view( widget ) ) return TRUE;
         if( Gtk::g_object_is_a( G_OBJECT( widget ), "SwtFixed" ) ) return TRUE;
 
         GtkWidget* parent(gtk_widget_get_parent(widget));
