@@ -59,10 +59,7 @@ namespace Oxygen
     GtkIcons::~GtkIcons( void )
     {
         if( _factory )
-        {
-            gtk_icon_factory_remove_default( _factory );
-            g_object_unref( G_OBJECT( _factory ) );
-        }
+        { gtk_icon_factory_remove_default( _factory ); }
     }
 
     //_________________________________________
@@ -261,6 +258,7 @@ namespace Oxygen
 
                 // add source to iconSet
                 gtk_icon_set_add_source( iconSet, iconSource );
+                gtk_icon_source_free( iconSource );
                 break;
 
             }
